summaryrefslogtreecommitdiffstats
path: root/config-model-api
diff options
context:
space:
mode:
authorJon Marius Venstad <venstad@gmail.com>2020-11-03 10:30:21 +0100
committerJon Marius Venstad <venstad@gmail.com>2020-11-03 10:30:21 +0100
commit157964dd3cf677e6abb3d9ba4d58bb6e4df2d94d (patch)
tree169168422a878d8b6d1b0f9875bbae618759680f /config-model-api
parentca78af4922f72f861c1cf88867e9159e697bad0f (diff)
Model reindexing status per cluster and document type
Diffstat (limited to 'config-model-api')
-rw-r--r--config-model-api/src/main/java/com/yahoo/config/model/api/Reindexing.java13
1 files changed, 6 insertions, 7 deletions
diff --git a/config-model-api/src/main/java/com/yahoo/config/model/api/Reindexing.java b/config-model-api/src/main/java/com/yahoo/config/model/api/Reindexing.java
index 0d37f6810a7..4dc06eae841 100644
--- a/config-model-api/src/main/java/com/yahoo/config/model/api/Reindexing.java
+++ b/config-model-api/src/main/java/com/yahoo/config/model/api/Reindexing.java
@@ -5,21 +5,20 @@ import java.time.Instant;
import java.util.Map;
/**
- * Instants after which reindexing should be triggered, for select document types.
+ * Status of reindexing for the documents of an application.
*
* @author jonmv
*/
public interface Reindexing {
- /** The reindexing status for each document type for which this is known. */
- default Map<String, ? extends Status> status() { return Map.of(); }
+ /** Reindexing status for a given application, cluster and document type. */
+ default Status status(String cluster, String documentType) { return () -> Instant.MAX; }
-
- /** Reindexing status of a given document type. */
+ /** Reindexing status of a given document type in a given cluster in a given application. */
interface Status {
- /** The instant at which reindexing of this document type may begin. */
- default Instant ready() { return Instant.MAX; };
+ /** The instant at which reindexing may begin. */
+ Instant ready();
}